pub struct CertVerification {
pub dns: Option<DnsUpdates>,
pub http: Option<HttpUpdate>,
}Expand description
A set of ACME challenges you can use to allow Hosting to create an SSL certificate for your domain name before directing traffic to Hosting servers. Use either the DNS or HTTP challenge; it’s not necessary to provide both.
This type is not used in any activity, and only used as part of another schema.
Fields
dns: Option<DnsUpdates>Output only. A TXT record to add to your DNS records that confirms your intent to let Hosting create an SSL cert for your domain name.
http: Option<HttpUpdate>Output only. A file to add to your existing, non-Hosting hosting service that confirms your intent to let Hosting create an SSL cert for your domain name.