Certificate

Struct Certificate 

pub struct Certificate {
    pub create_time: Option<DateTime<Utc>>,
    pub expire_time: Option<DateTime<Utc>>,
    pub issues: Option<Vec<Status>>,
    pub state: Option<String>,
    pub type_: Option<String>,
    pub verification: Option<CertVerification>,
}
An SSL certificate used to provide end-to-end encryption for requests against your domain name. A Certificate can be an actual SSL certificate or, for newly-created custom domains, Hosting’s intent to create one.

This type is not used in any activity, and only used as part of another schema.

Fields

create_time: Option<DateTime<Utc>>

Output only. The certificate’s creation time. For TEMPORARY certs this is the time Hosting first generated challenges for your domain name. For all other cert types, it’s the time the actual cert was created.

expire_time: Option<DateTime<Utc>>

Output only. The certificate’s expiration time. After this time, the cert can no longer be used to provide secure communication between Hosting and your site’s visitors.

issues: Option<Vec<Status>>

Output only. A set of errors Hosting encountered when attempting to create a cert for your domain name. Resolve these issues to ensure Hosting is able to provide secure communication with your site’s visitors.

state: Option<String>

Output only. The state of the certificate. Only the CERT_ACTIVE and CERT_EXPIRING_SOON states provide SSL coverage for a domain name. If the state is PROPAGATING and Hosting had an active cert for the domain name before, that formerly-active cert provides SSL coverage for the domain name until the current cert propagates.

type_: Option<String>

Output only. The certificate’s type.

verification: Option<CertVerification>

Output only. A set of ACME challenges you can add to your DNS records or existing, non-Hosting hosting provider to allow Hosting to create an SSL certificate for your domain name before you point traffic toward hosting. You can use thse challenges as part of a zero downtime transition from your old provider to Hosting.