pub struct DnsRecordSet {
pub check_error: Option<Status>,
pub domain_name: Option<String>,
pub records: Option<Vec<DnsRecord>>,
}Expand description
A set of DNS records relevant to the setup and maintenance of a custom domain in Firebase Hosting.
This type is not used in any activity, and only used as part of another schema.
Fields
check_error: Option<Status>Output only. An error Hosting services encountered when querying your domain name’s DNS records. Note: Hosting ignores NXDOMAIN errors, as those generally just mean that a domain name hasn’t been set up yet.
domain_name: Option<String>Output only. The domain name the record set pertains to.
records: Option<Vec<DnsRecord>>Output only. Records on the domain.