HttpUpdate

Struct HttpUpdate 

pub struct HttpUpdate {
    pub check_error: Option<Status>,
    pub desired: Option<String>,
    pub discovered: Option<String>,
    pub last_check_time: Option<DateTime<Utc>>,
    pub path: Option<String>,
}
A file you can add to your existing, non-Hosting hosting service that confirms your intent to allow Hosting’s Certificate Authorities to create an SSL certificate for your domain.

This type is not used in any activity, and only used as part of another schema.

Fields

check_error: Option<Status>

Output only. An error encountered during the last contents check. If null, the check completed successfully.

desired: Option<String>

Output only. A text string to serve at the path.

discovered: Option<String>

Output only. Whether Hosting was able to find the required file contents on the specified path during its last check.

last_check_time: Option<DateTime<Utc>>

Output only. The last time Hosting systems checked for the file contents.

path: Option<String>

Output only. The path to the file.