Struct google_firebasehosting1_beta1::api::PopulateVersionFilesRequest [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- sites versions populate files projects (request)
- versions populate files sites (request)
Fields
files: Option<HashMap<String, String>>A set of file paths to the hashes corresponding to assets that should be added to the version. A file path to an empty hash will remove the path from the version. Calculate a hash by Gzipping the file then taking the SHA256 hash of the newly compressed file.