Struct google_firebasehosting1_beta1::api::Version[][src]

pub struct Version {
    pub config: Option<ServingConfig>,
    pub create_time: Option<String>,
    pub create_user: Option<ActingUser>,
    pub delete_time: Option<String>,
    pub delete_user: Option<ActingUser>,
    pub file_count: Option<String>,
    pub finalize_time: Option<String>,
    pub finalize_user: Option<ActingUser>,
    pub labels: Option<HashMap<String, String>>,
    pub name: Option<String>,
    pub preview: Option<PreviewConfig>,
    pub status: Option<String>,
    pub version_bytes: Option<String>,
}

A Version is a configuration and a collection of static files which determine how a site is displayed.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

config: Option<ServingConfig>

The configuration for the behavior of the site. This configuration exists in the firebase.json file.

create_time: Option<String>

Output only. The time at which the version was created.

create_user: Option<ActingUser>

Output only. Identifies the user who created the version.

delete_time: Option<String>

Output only. The time at which the version was DELETED.

delete_user: Option<ActingUser>

Output only. Identifies the user who DELETED the version.

file_count: Option<String>

Output only. The total number of files associated with the version. This value is calculated after a version is FINALIZED.

finalize_time: Option<String>

Output only. The time at which the version was FINALIZED.

finalize_user: Option<ActingUser>

Output only. Identifies the user who FINALIZED the version.

labels: Option<HashMap<String, String>>

The labels used for extra metadata and/or filtering.

name: Option<String>

The fully-qualified resource name for the version, in the format: sites/ SITE_ID/versions/VERSION_ID This name is provided in the response body when you call CreateVersion.

preview: Option<PreviewConfig>

Deprecated in favor of site channels.

status: Option<String>

The deploy status of the version. For a successful deploy, call CreateVersion to make a new version (CREATED status), upload all desired files to the version, then update the version to the FINALIZED status. Note that if you leave the version in the CREATED state for more than 12 hours, the system will automatically mark the version as ABANDONED. You can also change the status of a version to DELETED by calling DeleteVersion.

version_bytes: Option<String>

Output only. The total stored bytesize of the version. This value is calculated after a version is FINALIZED.