Struct google_firebasehosting1_beta1::api::VersionFile [−][src]
A static content file that is part of a version.
This type is not used in any activity, and only used as part of another schema.
Fields
hash: Option<String>The SHA256 content hash of the file.
path: Option<String>The URI at which the file’s content should display.
status: Option<String>Output only. The current status of a particular file in the specified version. The value will be either pending upload or uploaded.