pub struct DnsUpdates {
pub check_time: Option<DateTime<Utc>>,
pub desired: Option<Vec<DnsRecordSet>>,
pub discovered: Option<Vec<DnsRecordSet>>,
}Expand description
A set of DNS record updates that you should make to allow Hosting to serve secure content in response to requests against your domain name. These updates present the current state of your domain name’s DNS records when Hosting last queried them, and the desired set of records that Hosting needs to see before your custom domain can be fully active.
This type is not used in any activity, and only used as part of another schema.
Fields
check_time: Option<DateTime<Utc>>The last time Hosting checked your custom domain’s DNS records.
desired: Option<Vec<DnsRecordSet>>The set of DNS records Hosting needs to serve secure content on the domain.
discovered: Option<Vec<DnsRecordSet>>The set of DNS records Hosting discovered when inspecting a domain.