Struct google_firebasehosting1_beta1::api::ListVersionFilesResponse [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- sites versions files list projects (response)
- versions files list sites (response)
Fields
files: Option<Vec<VersionFile>>The list of paths to the hashes of the files in the specified version.
next_page_token: Option<String>The pagination token, if more results exist beyond the ones in this response. Include this token in your next call to ListVersionFiles. Page tokens are short-lived and should not be stored.